Munch-mailsend
==============

Sending mass emails with `munch-core <https://github.com/crunchmail/munch-core>`_.
This is default backend for munch-core.

Developers
----------

Install with pip: :code:`pip install --process-dependency-links --trusted-host git.owk.cc -e .`

Run tests: :code:`munch django test munch_mailsend_tests --settings=munch_mailsend_tests.settings`
